Allen 2011


Notes
-----
Collection of resting-state network templates extracted from 600 healthy
subjects fMRI data.


Content
-------
    :"maps": T-maps of all 75 unthresholded components.
    :"rsn28": T-maps of 28 RSNs included in E. Allen et al.
    :"networks": string list containing the names for the 28 RSNs.
    :"rsn_indices": dict[rsn_name] -> list of int, indices in the "maps"
                    file of the 28 RSNs.
    :"comps": The aggregate ICA Components.

References
----------
For more information on this dataset's structure, see:
http://mialab.mrn.org/data/index.html

Resting state data from paper E. Allen, et al, "A baseline for the multivariate
comparison of resting state networks," Frontiers in Systems Neuroscience,
vol. 5, p. 12, 2011. http://dx.doi.org/10.3389/fnsys.2011.00002

Slices and label of the RSN ICs:
http://www.frontiersin.org/files/Articles/2093/fnsys-05-00002-HTML/image_m/fnsys-05-00002-g004.jpg

Licence: unknown.
